@@ -14,8 +14,7 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -56,7 +55,6 @@ nautilus_search_hit_compute_scores (NautilusSearchHit *hit,
 				    NautilusQuery     *query)
 {
 	GDateTime *now;
-	char *query_uri;
 	GFile *query_location;
 	GFile *hit_location;
 	GTimeSpan m_diff = G_MAXINT64;
@@ -66,8 +64,7 @@ nautilus_search_hit_compute_scores (NautilusSearchHit *hit,
 	gdouble proximity_bonus = 0.0;
 	gdouble match_bonus = 0.0;
 
-	query_uri = nautilus_query_get_location (query);
-	query_location = g_file_new_for_uri (query_uri);
+	query_location = nautilus_query_get_location (query);
 	hit_location = g_file_new_for_uri (hit->details->uri);
 
 	if (g_file_has_prefix (hit_location, query_location)) {
@@ -123,7 +120,6 @@ nautilus_search_hit_compute_scores (NautilusSearchHit *hit,
 	       proximity_bonus, recent_bonus, match_bonus);
 
 	g_date_time_unref (now);
-	g_free (query_uri);
 	g_object_unref (query_location);
 }
 
