@@ -46,12 +46,6 @@ static int  nautilus_notebook_insert_page	 (GtkNotebook *notebook,
 static void nautilus_notebook_remove	 (GtkContainer *container,
 					  GtkWidget *tab_widget);
 
-static const GtkTargetEntry url_drag_types[] = 
-{
-	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
-	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
-};
-
 enum
 {
 	TAB_CLOSE_REQUEST,
@@ -173,19 +167,6 @@ nautilus_notebook_init (NautilusNotebook *notebook)
 
 	g_signal_connect (notebook, "button-press-event",
 			  (GCallback)button_press_cb, NULL);
-
-	/* Set up drag-and-drop target */
-	/* TODO this would be used for opening a new tab.
-	 * It will only work properly as soon as GtkNotebook 
-	 * supports to find out whether a particular point
-	 * is on a tab button or not.
-	 */
-#if 0
-	gtk_drag_dest_set (GTK_WIDGET (notebook), 0,
-			   url_drag_types, G_N_ELEMENTS (url_drag_types),
-			   GDK_ACTION_LINK);
-	gtk_drag_dest_set_track_motion (GTK_WIDGET (notebook), TRUE);
-#endif
 }
 
 gboolean
@@ -332,7 +313,7 @@ build_tab_label (NautilusNotebook *nb, NautilusWindowSlot *slot)
 	gtk_button_set_relief (GTK_BUTTON (close_button),
 			       GTK_RELIEF_NONE);
 	/* don't allow focus on the close button */
-	gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
+	gtk_widget_set_focus_on_click (GTK_WIDGET (close_button), FALSE);
 
 	gtk_widget_set_name (close_button, "nautilus-tab-close-button");
 
