@@ -915,7 +915,8 @@ open_location_cb (NautilusWindow     *window,
 
 	switch (open_flags) {
 	case GTK_PLACES_OPEN_NEW_TAB:
-		flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+                flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB |
+                        NAUTILUS_WINDOW_OPEN_FLAG_DONT_MAKE_ACTIVE;
 		break;
 
 	case GTK_PLACES_OPEN_NEW_WINDOW:
@@ -1270,8 +1271,6 @@ add_menu_separator (GtkWidget *menu)
 
         separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
         gtk_container_add (GTK_CONTAINER (menu), separator);
-        gtk_widget_set_margin_top (separator, 6);
-        gtk_widget_set_margin_bottom (separator, 6);
         gtk_widget_show (separator);
 }
 
